@@ -22,8 +22,11 @@ dataUploadUI <- function(id){
                h3("Data upload"),
                fileInput(ns("datafile"), "Upload a csv or sas7bdat file",accept = c(".sas7bdat", ".csv"), multiple = TRUE),
                radioButtons(ns("select_file"),"Select file for safetyGraphics charts",
-                            choiceNames = list(HTML("<p>Example data - <em style='color:green; font-size:12px;'>ADaM</em></p>")),
-                            choiceValues = "Example data")
+                            choiceNames = preload_data_list$display,
+                            choiceValues = names(preload_data_list$data))
+               # radioButtons(ns("select_file"),"Select file for safetyGraphics charts",
+               #              choiceNames = list(HTML("<p>Example data - <em style='color:green; font-size:12px;'>ADaM</em></p>")),
+               #              choiceValues = "Example data")
              )
       ),
       column(6,
