@@ -2,19 +2,25 @@ context("Tests for the getRequiredSettings() function")
 library(safetyGraphics)
 library(testthat)
 
-defaultRequiredCols <- list(
+defaultRequiredSettings <- list(
   list("id_col"),
   list("value_col"),
   list("measure_col"),
+  list("measure_values","ALT"),
+  list("measure_values","AST"),
+  list("measure_values","TB"),
+  list("measure_values","ALP"),
   list("normal_col_low"),
   list("normal_col_high"),
-  list("studyday_col")
+  list("studyday_col"),
+  list("visit_col"),
+  list("visitn_col")
 )
 
 
 customMetadata<- data.frame(
-  chart_linechart = c(TRUE, FALSE), 
-  chart_barchart = c(FALSE,TRUE), 
+  chart_linechart = c(TRUE, FALSE),
+  chart_barchart = c(FALSE,TRUE),
   text_key = c("line_col","value_col--label"),
   label=c("label1","label2"),
   description=c("desc1","desc2"),
@@ -22,7 +28,6 @@ customMetadata<- data.frame(
   setting_required=TRUE,
   column_mapping=TRUE,
   column_type="character",
-  column_required=TRUE,
   field_mapping=FALSE
 )
 
@@ -30,7 +35,7 @@ customMetadata<- data.frame(
 test_that("default function call works as expected",{
   a<- safetyGraphics::getRequiredSettings()
   expect_is(a,"list")
-  expect_equal(a,defaultRequiredCols)
+  expect_equal(a,defaultRequiredSettings)
 })
 
 test_that("options work as expected",{
@@ -47,4 +52,4 @@ test_that("nested keys are supported",{
 
 test_that("invalid options return null",{
   expect_null(safetyGraphics::getRequiredSettings(chart="notachart"))
-})
\ No newline at end of file
+})
